@@ -1,13 +1,16 @@
-#!/usr/bin/env python
+#!/usr/bin/env python3
 """Increase lightness"""
 
 import inkex
 
+
 class MoreLight(inkex.ColorExtension):
     """Lighten selected objects"""
+
     def modify_color(self, name, color):
         color.lightness += int(0.05 * 255.0)
         return color
 
-if __name__ == '__main__':
+
+if __name__ == "__main__":
     MoreLight().run()
